#ifndef NT2_INCLUDE_FUNCTIONS_IS_GEZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_GEZ_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_gez.hpp>

#endif
